<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλέξτε γλώσσα εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλώ επανεκκινήστε το πρόγραμμα για εφαρμογή της αλλαγής στη γλώσσα.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Αναφορά κατανομής χρόνου</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Εταιρεία:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Διεύθυνση:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Τηλέφωνο:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Φαξ:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Ιστότοπος:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Μη διαθέσιμο</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Προηγείται το σύμβολο νομίσματος</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Ωρομίσθιο:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>ΦΠΑ:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Σύμβολο νομίσματος:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Στοιχεία επικοινωνίας</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Δεδομένα</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Ιστοσελίδα (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>Outlook CSV (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Εξαγωγή αναφοράς</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Προβολή αναφορών</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Δημιουργία αναφοράς</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Τηλέφωνο: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Φαξ: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ώρες</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Μερικό σύνολο</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Φόροι</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Σύνολο</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n ώρα</numerusform>
            <numerusform>%n ώρες</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 ώρες</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Η συνεδρία έρχεται σε διένεξη με άλλες συνεδρίες.</translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Προσθήκη συνεδρίας</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Ημερομηνία:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Έναρξη:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Διακοπή:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Εργασία:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Επεξεργασία συνεδρίας</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation>Σύνολο</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Task</source>
        <translation>Εργασία</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Ώρες</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Ημερήσια</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Εβδομαδιαία</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Μηνιαία</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Αναφορά</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Έναρξη</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Ελαχιστοποίηση</translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>Έρ&amp;γο</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Προσθήκη</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+Ν</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Απαλοιφή</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Συνεδρία</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Ctrl+Delete</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Στήλες</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>Σύνολα σε &amp;δεκαδική μορφή</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;Επεξεργασία στη γραμμή</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Γλώσσα προγράμματος...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Περί</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Περί &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Έργο</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Χρονόμετρο</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Εμφάνιση όλων</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Εμφάνιση μόνο μη τιμολογημένων</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Εμφάνιση μόνο αυτό το έτος</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Εμφάνιση μόνο αυτό το μήνα</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Εμφάνιση μόνο αυτή την εβδομάδα</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Κυκλοφορεί υπό την Γενική Δημόσια Άδεια &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Η συνεδρία έρχεται σε διένεξη με άλλες συνεδρίες.</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>Επανα&amp;φορά</translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Δεν ήταν δυνατή η ανάγνωση των δεδομένων χρόνου.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Ανώνυμο</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Δεν ήταν δυνατή η εγγραφή των δεδομένων χρόνου.</translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Υπάρχουν χρονόμετρα σε λειτουργία. Διακοπή χρονομέτρων και έξοδος;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Πρόγραμμα παρακολούθησης χρόνου εργασίας</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>&amp;Δημιουργία αναφοράς...</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Π&amp;ροβολή αναφορών</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Ακύρωση αυτής της συνεδρίας;</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Προσθήκη έργου</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Εισαγωγή ονόματος έργου:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Δεν ήταν δυνατή η δημιουργία θέσης δεδομένων χρόνου.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Δεν ήταν δυνατή η μετακίνηση της θέσης δεδομένων χρόνου.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Υπάρχει ήδη ένα έργο με αυτό το όνομα.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Απαλοιφή επιλεγμένου έργου;</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Απαλοιφή επιλεγμένης συνεδρίας;</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n χρονόμετρο λειτουργεί</numerusform>
            <numerusform>%n χρονόμετρα λειτουργούν</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Kapow Punch Clock</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation>Πρόγραμμα χρονομέτρου εργασίας</translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation>Αποθήκευση ρυθμίσεων με μορφή INI στο καθορισμένο αρχείο.</translation>
    </message>
    <message>
        <source>file</source>
        <translation>αρχείο</translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation>Όχι αυτόματη δημιουργία αντιγράφων ασφαλείας των δεδομένων χρόνου.</translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation>Το αρχείο δεδομένων χρόνου που θα χρησιμοποιηθεί.</translation>
    </message>
</context>
</TS>
